require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_defaultgatewayaddress',
  dscmeta_resource_friendly_name: 'DefaultGatewayAddress',
  dscmeta_resource_name: 'DSC_DefaultGatewayAddress',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '8.2.0',
  docs: 'The DSC DefaultGatewayAddress resource type.
         Automatically generated from version 8.2.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_interfacealias: {
      type: 'String',
      desc: 'Alias of the network interface for which the default gateway address is set.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_address: {
      type: 'Optional[String]',
      desc: 'The desired default gateway address - if not provided default gateway will be removed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_addressfamily: {
      type: "Enum['IPv4', 'IPv6']",
      desc: 'IP address family.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
