require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_dnsclientglobalsetting',
  dscmeta_resource_friendly_name: 'DnsClientGlobalSetting',
  dscmeta_resource_name: 'DSC_DnsClientGlobalSetting',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '8.2.0',
  docs: 'The DSC DnsClientGlobalSetting resource type.
         Automatically generated from version 8.2.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_suffixsearchlist: {
      type: 'Optional[Array[String]]',
      desc: 'Specifies a list of global suffixes that can be used in the specified order by the DNS client for resolving the IP address of the computer name.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_issingleinstance: {
      type: "Enum['Yes']",
      desc: "Specifies the resource is a single instance, the value must be 'Yes'.",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_usedevolution: {
      type: 'Optional[Boolean]',
      desc: 'Specifies that devolution is activated.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_devolutionlevel: {
      type: 'Optional[Integer[0, 4294967295]]',
      desc: 'Specifies the number of labels up to which devolution should occur.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt32',
      mof_is_embedded: false,
    },
  },
)
