require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_dnsserveraddress',
  dscmeta_resource_friendly_name: 'DnsServerAddress',
  dscmeta_resource_name: 'DSC_DnsServerAddress',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '8.2.0',
  docs: 'The DSC DnsServerAddress resource type.
         Automatically generated from version 8.2.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_interfacealias: {
      type: 'String',
      desc: 'Alias of the network interface for which the DNS server address is set.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_validate: {
      type: 'Optional[Boolean]',
      desc: "Requires that the DNS Server addresses be validated if they are updated. It will cause the resource to throw a 'A general error occurred that is not covered by a more specific error code.' error if set to True and specified DNS Servers are not accessible.",
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_address: {
      type: 'Optional[Array[String]]',
      desc: 'The desired DNS Server address(es). Exclude to enable DHCP.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_addressfamily: {
      type: "Enum['IPv4', 'IPv6']",
      desc: 'IP address family.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
