require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_hostsfile',
  dscmeta_resource_friendly_name: 'HostsFile',
  dscmeta_resource_name: 'DSC_HostsFile',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '8.2.0',
  docs: 'The DSC HostsFile resource type.
         Automatically generated from version 8.2.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_hostname: {
      type: 'String',
      desc: 'Specifies the name of the computer that will be mapped to an IP address.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ipaddress: {
      type: 'Optional[String]',
      desc: 'Specifies the IP Address that should be mapped to the host name.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specifies if the hosts file entry should be created or deleted.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
