require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_ipaddress',
  dscmeta_resource_friendly_name: 'IPAddress',
  dscmeta_resource_name: 'DSC_IPAddress',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '8.2.0',
  docs: 'The DSC IPAddress resource type.
         Automatically generated from version 8.2.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_interfacealias: {
      type: 'String',
      desc: 'Alias of the network interface for which the IP address should be set.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_keepexistingaddress: {
      type: 'Optional[Boolean]',
      desc: 'Indicates whether or not existing IP addresses on an interface will be retained.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ipaddress: {
      type: 'Optional[Array[String]]',
      desc: 'The desired IP address, optionally including prefix length using CIDR notation.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_addressfamily: {
      type: "Enum['IPv4', 'IPv6']",
      desc: 'IP address family.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
