require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_netadapterbinding',
  dscmeta_resource_friendly_name: 'NetAdapterBinding',
  dscmeta_resource_name: 'DSC_NetAdapterBinding',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '8.2.0',
  docs: 'The DSC NetAdapterBinding resource type.
         Automatically generated from version 8.2.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_currentstate: {
      type: "Optional[Enum['Enabled', 'Disabled', 'Mixed']]",
      desc: 'Returns the current state of the component ID for the Interfaces.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interfacealias: {
      type: 'String',
      desc: "Specifies the alias of a network interface. Supports the use of '*'.",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_componentid: {
      type: 'String',
      desc: 'Specifies the underlying name of the transport or filter in the following form - ms_xxxx, such as ms_tcpip.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_state: {
      type: "Optional[Enum['Enabled', 'Disabled']]",
      desc: 'Specifies if the component ID for the Interface should be Enabled or Disabled.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
