require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_netbios',
  dscmeta_resource_friendly_name: 'NetBios',
  dscmeta_resource_name: 'DSC_NetBios',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '8.2.0',
  docs: 'The DSC NetBios resource type.
         Automatically generated from version 8.2.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_setting: {
      type: "Enum['Default', 'Enable', 'Disable']",
      desc: 'Specifies if NetBIOS should be enabled or disabled or obtained from the DHCP server (Default). If static IP, Enable NetBIOS.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interfacealias: {
      type: 'String',
      desc: "Specifies the alias of a network interface. Supports the use of '*' and '%'",
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
  },
)
