require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_netconnectionprofile',
  dscmeta_resource_friendly_name: 'NetConnectionProfile',
  dscmeta_resource_name: 'DSC_NetConnectionProfile',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '8.2.0',
  docs: 'The DSC NetConnectionProfile resource type.
         Automatically generated from version 8.2.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_networkcategory: {
      type: "Optional[Enum['Public', 'Private']]",
      desc: 'Specifies the IPv6 Connection Value.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interfacealias: {
      type: 'String',
      desc: 'Specifies the alias for the Interface that is being changed.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ipv4connectivity: {
      type: "Optional[Enum['Disconnected', 'NoTraffic', 'Subnet', 'LocalNetwork', 'Internet']]",
      desc: 'Sets the Network Category for the interface.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_ipv6connectivity: {
      type: "Optional[Enum['Disconnected', 'NoTraffic', 'Subnet', 'LocalNetwork', 'Internet']]",
      desc: 'Specifies the IPv4 Connection Value.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
