require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_networkteam',
  dscmeta_resource_friendly_name: 'NetworkTeam',
  dscmeta_resource_name: 'DSC_NetworkTeam',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '8.2.0',
  docs: 'The DSC NetworkTeam resource type.
         Automatically generated from version 8.2.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_teamingmode: {
      type: "Optional[Enum['SwitchIndependent', 'LACP', 'Static']]",
      desc: 'Specifies the teaming mode configuration.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: "Specifies if the network team should be created or deleted. Defaults to 'Present'.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_name: {
      type: 'String',
      desc: 'Specifies the name of the network team to create.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_teammembers: {
      type: 'Array[String]',
      desc: 'Specifies the network interfaces that should be a part of the network team. This is a comma-separated list.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
    dsc_loadbalancingalgorithm: {
      type: "Optional[Enum['Dynamic', 'HyperVPort', 'IPAddresses', 'MacAddresses', 'TransportPorts']]",
      desc: 'Specifies the load balancing algorithm for the network team.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
