require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_route',
  dscmeta_resource_friendly_name: 'Route',
  dscmeta_resource_name: 'DSC_Route',
  dscmeta_module_name: 'NetworkingDsc',
  dscmeta_module_version: '8.2.0',
  docs: 'The DSC Route resource type.
         Automatically generated from version 8.2.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_destinationprefix: {
      type: 'String',
      desc: 'Specifies a destination prefix of an IP route. A destination prefix consists of an IP address prefix and a prefix length, separated by a slash (/).',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_addressfamily: {
      type: "Enum['IPv4', 'IPv6']",
      desc: 'Specifies the IP address family.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: "Specifies whether the route should exist. Defaults to 'Present'.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_routemetric: {
      type: 'Optional[Integer[0, 65535]]',
      desc: 'Specifies an integer route metric for an IP route. Defaults to 256.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'UInt16',
      mof_is_embedded: false,
    },
    dsc_publish: {
      type: "Optional[Enum['No', 'Yes', 'Age']]",
      desc: "Specifies the publish setting of an IP route. Defaults to 'No'.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_preferredlifetime: {
      type: 'Optional[Float]',
      desc: 'Specifies a preferred lifetime in seconds of an IP route.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Real64',
      mof_is_embedded: false,
    },
    dsc_nexthop: {
      type: 'String',
      desc: 'Specifies the next hop for the IP route.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_interfacealias: {
      type: 'String',
      desc: 'Specifies the alias of a network interface.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
